@@ -91,6 +91,26 @@ module Y2Storage
       mount_point.mount_options
     end
 
+    # Mount options that may be needed for the system to boot correctly, but that are not currently
+    # part of #{mount_options}
+    #
+    # @see MountPoint#adjust_mount_options
+    #
+    # @return [Array<String>]
+    def missing_mount_options
+      []
+    end
+
+    # Mount options that are currently part of #{mount_options} but that may prevent a correct
+    # system boot
+    #
+    # @see MountPoint#adjust_mount_options
+    #
+    # @return [Array<String>]
+    def unwanted_mount_options
+      []
+    end
+
     # Is the mount persistent?
     #
     # @return [Boolean] true if the mount point is saved to /etc/fstab
@@ -110,6 +130,18 @@ module Y2Storage
       mount_point.root?
     end
 
+    # Whether the device contains a mount point that returns true for the given block or whether the
+    # device is based in the same disk than another device containing such a mount point
+    #
+    # @return [Boolean]
+    def disk_with_mount_point?(&block)
+      return true if mount_point && block.call(mount_point)
+
+      ([self] + ancestors).any? do |dev|
+        dev.is_a?(BlkDevice) && dev.contain_mount_point?(&block)
+      end
+    end
+
     # Creates a mount point object for the device
     #
     # @param path [String]
@@ -120,20 +152,10 @@ module Y2Storage
       mp.path = path
       # Recalculate etc status for the parent devices
       update_etc_status
-      # Recalculate the crypt_options for parent encryption devices
-      adjust_crypt_options
+      # Recalculate the crypt_options and mount_by for parent encryption devices
+      adjust_crypt_devices
       # Ensure the mount_by makes sense
       mp.ensure_suitable_mount_by
-      # Adjust mount_by for encryption layer: try to use the same mount_by
-      # type as for the filesystem
-      if mp.filesystem.encrypted?
-        mp.filesystem.blk_devices.each do |dev|
-          next unless dev.respond_to?(:mount_by)
-
-          dev.mount_by = mp.mount_by
-          dev.ensure_suitable_mount_by
-        end
-      end
       mp
     end
 
@@ -142,7 +164,7 @@ module Y2Storage
     # @raise [Storage::Exception] if the mountable has no mount point
     def remove_mount_point
       storage_remove_mount_point
-      adjust_crypt_options
+      adjust_crypt_devices
       update_etc_status
     end
 
@@ -160,6 +182,18 @@ module Y2Storage
       ancestors.select { |d| d.is?(:encryption) }.each(&:adjust_crypt_options)
     end
 
+    # Updates the crypttab options and the mount_by value for all the associated
+    # encryption devices
+    #
+    # @see Encryption#adjust_crypt_options
+    # @see Encryption#adjust_mount_by
+    def adjust_crypt_devices
+      ancestors.select { |d| d.is?(:encryption) }.each do |enc|
+        enc.adjust_mount_by
+        enc.adjust_crypt_options
+      end
+    end
+
     # Mount options proposed by YaST for mount points associated to this device,
     # in addition to the ones returned by libstorage-ng
     #
