@@ -1,7 +1,3 @@
-#!/usr/bin/env ruby
-#
-# encoding: utf-8
-
 # Copyright (c) [2015-2017] SUSE LLC
 #
 # All Rights Reserved.
@@ -244,7 +240,7 @@ module Y2Storage
     # @return [Array<Hash>]
     #
     # FIXME: this method offends three different complexity cops!
-    # rubocop:disable Metrics/CyclomaticComplexity, Metrics/PerceivedComplexity, Metrics/AbcSize
+    # rubocop:disable Metrics/AbcSize, Metrics/PerceivedComplexity, Metrics/CyclomaticComplexity
     def yaml_disk_device_partitions(device)
       partition_end = 0
       partition_end_max = 0
@@ -263,7 +259,7 @@ module Y2Storage
 
         # is there a gap before the partition?
         # note: gap might actually be negative sometimes!
-        gap = partition.region.start * partition.region.block_size.to_i - partition_end
+        gap = (partition.region.start * partition.region.block_size.to_i) - partition_end
         partitions << yaml_free_slot(DiskSize.B(partition_end), DiskSize.B(gap)) if gap > 0
 
         # show partition itself
@@ -290,7 +286,7 @@ module Y2Storage
 
       # see if there's space left at the end of the device
       # show also negative sizes so we know we've overstepped
-      gap = next_start(device.region) * device.region.block_size.to_i - partition_end_max
+      gap = (next_start(device.region) * device.region.block_size.to_i) - partition_end_max
       partitions << yaml_free_slot(DiskSize.B(partition_end_max), DiskSize.B(gap)) if gap != 0
 
       partitions
